OiRA - Évaluation interactive des risques en ligne

# Rapport

Maintenant que vous avez fini d'identifier tous les risques dans votre organisation et créé un plan d'action, vous pouvez créer un rapport qui répertorie tous vos résultats. Vous pouvez, si vous le voulez, ajouter des commentaires supplémentaires qui seront inclus dans ce rapport dans le champ ci-dessous. Vous pouvez également télécharger ce rapport et l'enregistrer sur votre ordinateur. Vous pourrez ainsi le personnaliser, le compléter et le modifier comme vous le souhaitez.

pilz@syslab.com

http://www.surveymonkey.com/s/OiRATool

Veuillez nous faire part de votre feedback sur cet outil : cela ne vous prendra que 3 minutes ! Nous apprécions vraiment votre contribution pendant cette phase de test de l'outil OiRA.

Aller à l'enquête

Non merci

1. Préparation
2. Identification
3. Estimation
4. Plan d'action
5. Rapport

Produit par EU-OSHA. | À propos | Confidentialité | Décharge de responsabilité | Licence GPL |